@@ -1,6 +1,6 @@
 package Date::WeekNumber;
 # ABSTRACT: calculate week of the year (ISO 8601 weeks, or 'CPAN weeks')
-$Date::WeekNumber::VERSION = '0.04';
+$Date::WeekNumber::VERSION = '0.05';
 use 5.006;
 use strict;
 use warnings;
@@ -220,7 +220,7 @@ you can still request the old week numbering scheme.
 
 =head1 REPOSITORY
 
-L<https://github.com/neilbowers/Date-WeekNumber>
+L<https://github.com/neilb/Date-WeekNumber>
 
 =head1 AUTHOR
 
